#include <iostream>
#include <algorithm>
#include <cstdint>
#include <cstdlib>
#include <map>
#include <new>

using namespace std;

enum ACTS { N = 0, L, R, H, V, D, A, DR };
map<char, ACTS> COM_CODES = {{'<', L}, {'>', R}, {'-', H},
    {'|', V}, {'\\', D}, {'/', A}};

ACTS * encode_intcms(string coms) {
    int size = coms.length();
    ACTS *res = new ACTS[size];
    for (int i = 0; i < size; i++) {
        res[i] = COM_CODES[coms[i]];
    }
    
    return res;
}

ACTS OPTIM_MTX[8][8] = {
    {N, L, R, H, V, D, A, DR},
    {L, DR, N, D, A, V, H, R},
    {R, N, DR, A, D, H, V, L},
    {H, A, D, N, DR, R, L, V},
    {V, D, A, DR, N, L, R, H},
    {D, H, V, L, R, N, DR, A},
    {A, V, H, R, L, DR, N, D},
    {DR, R, L, V, H, D, A, N}
};

ACTS optimize_coms(ACTS * coms, int count) {
    ACTS a = coms[0];
    for (int i = 1; i < count; ++i) {
        a = OPTIM_MTX[a][coms[i]];
    }
    
    return a;
}

inline void rotate_char_hor(char& a) {
    switch(a) {
        case '^':
            a = 'v';
            break;
        case 'v':
            a = '^';
            break;
        case '/':
            a = '\\';
            break;
        case '\\':
            a = '/';
            break;
    }
}

inline void rotate_char_vert(char& a) {
    switch(a) {
        case '>':
            a = '<';
            break;
        case '<':
            a = '>';
            break;
        case '|':
            a = '-';
            break;
        case '-':
            a = '|';
            break;
        case '/':
            a = '\\';
            break;
        case '\\':
            a = '/';
            break;
    }
}

inline void rotate_char_left(char& a) {
    switch(a) {
        case '<':
            a = 'v';
            break;
        case 'v':
            a = '>';
            break;
        case '>':
            a = '^';
            break;
        case '^':
            a = '<';
            break;
        case '|':
            a = '-';
            break;
        case '-':
            a = '|';
            break;
        case '/':
            a = '\\';
            break;
        case '\\':
            a = '/';
            break;
    }
}

inline void left_rotate(char** display, int count) {
    char temp[count][count];
    for (int i = 0; i < count; ++i){
        for (int j = 0; j < count; j++) {
            temp[count - j - 1][i] = display[i][j];
            rotate_char_left(temp[count - j - 1][i]);
        }

    }
    
    for (int i = 0; i < count; i++) {
        for (int j = 0; j < count; j++) {
            display[i][j] = temp[i][j];
        }


    }

}

inline void hor_transp(char** display, int count){
    for (int i = 0; i < count/2; ++i) {
        for (int j = 0; j < count; ++j) {
            swap(display[i][j], display[count - i - 1][j]);
            rotate_char_hor(display[i][j]);
            rotate_char_hor(display[count - i - 1][j]);
        }
    }
}

inline void vert_transp(char** display, int count){
    for (int i = 0; i < count; ++i) {
        for (int j = 0; j < count/2; ++j) {
            swap(display[i][j], display[i][count - j - 1]);
            rotate_char_vert(display[i][j]);
            rotate_char_vert(display[i][count - j - 1]);
        }
    }
}

inline void execute(char **display, int count, ACTS com) {
    switch (com) {
        case ACTS::N: 
            break;
        case ACTS::L: 
            left_rotate(display, N);
            break;
        case ACTS::R: 
            left_rotate(display, N);
            left_rotate(display, N);
            left_rotate(display, N);
            break;
        case ACTS::H: 
            hor_transp(display, N);
            break;
        case ACTS::V: 
            vert_transp(display, N);
            break;
        case ACTS::D: 
            left_rotate(display, N);
            left_rotate(display, N);
            left_rotate(display, N);
            vert_transp(display, N);
            break;
        case ACTS::A: 
            left_rotate(display, N);
            hor_transp(display, N);
            
            break;
    }
}

inline void print_display(char **display, int N) {
    for (int i = 0; i < N; i++) {
        for (int j = 0; j < N; j++) {
            cout << display[i][j];
        }
        cout << endl;
    }

}

inline void solve(int N) {
    char **display;
    display = new char*[N];
    
    for (int i = 0; i < N; i++) {
        display[i] = new char[N];
        for (int j = 0; j < N; j++) {
            cin >> display[i][j];
        }
    }
    
    string coms;
    cin >> coms;
    
    ACTS * int_coms = encode_intcms(coms);
    int count = coms.size();
    ACTS com = optimize_coms(int_coms, count);
    execute(display, N, com);
    print_display(display, N);
    
    for (int i = 0; i < N; i++) {
        delete[] display[i];
    }
    delete[] display;
}

int main(int argc, char** argv) {
    int N;
    while (cin >> N) {
        solve(N);
    }
    
    return 0;
}

